<a id="types-aiobotocore-ecs"></a>

# types-aiobotocore-ecs

[![PyPI - types-aiobotocore-ecs](https://img.shields.io/pypi/v/types-aiobotocore-ecs.svg?color=blue)](https://pypi.org/project/types-aiobotocore-ecs)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-ecs.svg?color=blue)](https://pypi.org/project/types-aiobotocore-ecs)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-ecs?color=blue)](https://pypistats.org/packages/types-aiobotocore-ecs)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.ECS 2.3.1](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ecs.html#ECS)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.5.14](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-ecs docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ecs/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-ecs](#types-aiobotocore-ecs)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `ECS`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `ECS` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[ecs]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[ecs]'


# standalone installation
python -m pip install types-aiobotocore-ecs
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-ecs
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[ecs]` in your environment:

```bash
python -m pip install 'types-aiobotocore[ecs]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[ecs]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[ecs]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[ecs]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[ecs]` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[ecs]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[ecs]` in your environment:

```bash
python -m pip install 'types-aiobotocore[ecs]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[ecs]` in your environment:

```bash
python -m pip install 'types-aiobotocore[ecs]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ECSClient` provides annotations for `session.create_client("ecs")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_ecs import ECSClient

session = get_session()
async with session.create_client("ecs") as client:
    client: ECSClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_ecs.paginator` module contains type annotations for all
paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_ecs import ECSClient
from types_aiobotocore_ecs.paginator import (
    ListAccountSettingsPaginator,
    ListAttributesPaginator,
    ListClustersPaginator,
    ListContainerInstancesPaginator,
    ListServicesPaginator,
    ListTaskDefinitionFamiliesPaginator,
    ListTaskDefinitionsPaginator,
    ListTasksPaginator,
)

session = get_session()
async with session.create_client("ecs") as client:
    client: ECSClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        list_account_settings_paginator: ListAccountSettingsPaginator = client.get_paginator("list_account_settings")
        list_attributes_paginator: ListAttributesPaginator = client.get_paginator("list_attributes")
        list_clusters_paginator: ListClustersPaginator = client.get_paginator("list_clusters")
        list_container_instances_paginator: ListContainerInstancesPaginator = client.get_paginator("list_container_instances")
        list_services_paginator: ListServicesPaginator = client.get_paginator("list_services")
        list_task_definition_families_paginator: ListTaskDefinitionFamiliesPaginator = client.get_paginator("list_task_definition_families")
        list_task_definitions_paginator: ListTaskDefinitionsPaginator = client.get_paginator("list_task_definitions")
        list_tasks_paginator: ListTasksPaginator = client.get_paginator("list_tasks")
    ```


### Waiters annotations

`types_aiobotocore_ecs.waiter` module contains type annotations for all waiters.

```python
from aiobotocore.session import get_session

from types_aiobotocore_ecs.client import ECSClient
from types_aiobotocore_ecs.waiter import (
    ServicesInactiveWaiter,
    ServicesStableWaiter,
    TasksRunningWaiter,
    TasksStoppedWaiter,
)

session = get_session()
async with session.create_client("ecs") as client:
    client: ECSClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        services_inactive_waiter: ServicesInactiveWaiter = client.get_waiter("services_inactive")
        services_stable_waiter: ServicesStableWaiter = client.get_waiter("services_stable")
        tasks_running_waiter: TasksRunningWaiter = client.get_waiter("tasks_running")
        tasks_stopped_waiter: TasksStoppedWaiter = client.get_waiter("tasks_stopped")
    ```





<a id="literals"></a>

### Literals

`types_aiobotocore_ecs.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_ecs.literals import (
    AgentUpdateStatusType,
    AssignPublicIpType,
    CPUArchitectureType,
    CapacityProviderFieldType,
    CapacityProviderStatusType,
    CapacityProviderUpdateStatusType,
    ClusterFieldType,
    ClusterSettingNameType,
    CompatibilityType,
    ConnectivityType,
    ContainerConditionType,
    ContainerInstanceFieldType,
    ContainerInstanceStatusType,
    DeploymentControllerTypeType,
    DeploymentRolloutStateType,
    DesiredStatusType,
    DeviceCgroupPermissionType,
    EFSAuthorizationConfigIAMType,
    EFSTransitEncryptionType,
    EnvironmentFileTypeType,
    ExecuteCommandLoggingType,
    FirelensConfigurationTypeType,
    HealthStatusType,
    InstanceHealthCheckStateType,
    InstanceHealthCheckTypeType,
    IpcModeType,
    LaunchTypeType,
    ListAccountSettingsPaginatorName,
    ListAttributesPaginatorName,
    ListClustersPaginatorName,
    ListContainerInstancesPaginatorName,
    ListServicesPaginatorName,
    ListTaskDefinitionFamiliesPaginatorName,
    ListTaskDefinitionsPaginatorName,
    ListTasksPaginatorName,
    LogDriverType,
    ManagedAgentNameType,
    ManagedScalingStatusType,
    ManagedTerminationProtectionType,
    NetworkModeType,
    OSFamilyType,
    PidModeType,
    PlacementConstraintTypeType,
    PlacementStrategyTypeType,
    PlatformDeviceTypeType,
    PropagateTagsType,
    ProxyConfigurationTypeType,
    ResourceTypeType,
    ScaleUnitType,
    SchedulingStrategyType,
    ScopeType,
    ServiceFieldType,
    ServicesInactiveWaiterName,
    ServicesStableWaiterName,
    SettingNameType,
    SortOrderType,
    StabilityStatusType,
    TargetTypeType,
    TaskDefinitionFamilyStatusType,
    TaskDefinitionFieldType,
    TaskDefinitionPlacementConstraintTypeType,
    TaskDefinitionStatusType,
    TaskFieldType,
    TaskSetFieldType,
    TaskStopCodeType,
    TasksRunningWaiterName,
    TasksStoppedWaiterName,
    TransportProtocolType,
    UlimitNameType,
    ECSServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    WaiterName,
    RegionName,
)

def check_value(value: AgentUpdateStatusType) -> bool:
    ...
````

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_ecs.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_ecs.type_defs import (
    AttachmentStateChangeTypeDef,
    AttachmentTypeDef,
    AttributeTypeDef,
    AutoScalingGroupProviderTypeDef,
    AutoScalingGroupProviderUpdateTypeDef,
    AwsVpcConfigurationTypeDef,
    CapacityProviderStrategyItemTypeDef,
    CapacityProviderTypeDef,
    ClusterConfigurationTypeDef,
    ClusterSettingTypeDef,
    ClusterTypeDef,
    ContainerDefinitionTypeDef,
    ContainerDependencyTypeDef,
    ContainerInstanceHealthStatusTypeDef,
    ContainerInstanceTypeDef,
    ContainerOverrideTypeDef,
    ContainerStateChangeTypeDef,
    ContainerTypeDef,
    CreateCapacityProviderRequestRequestTypeDef,
    CreateCapacityProviderResponseTypeDef,
    CreateClusterRequestRequestTypeDef,
    CreateClusterResponseTypeDef,
    CreateServiceRequestRequestTypeDef,
    CreateServiceResponseTypeDef,
    CreateTaskSetRequestRequestTypeDef,
    CreateTaskSetResponseTypeDef,
    DeleteAccountSettingRequestRequestTypeDef,
    DeleteAccountSettingResponseTypeDef,
    DeleteAttributesRequestRequestTypeDef,
    DeleteAttributesResponseTypeDef,
    DeleteCapacityProviderRequestRequestTypeDef,
    DeleteCapacityProviderResponseTypeDef,
    DeleteClusterRequestRequestTypeDef,
    DeleteClusterResponseTypeDef,
    DeleteServiceRequestRequestTypeDef,
    DeleteServiceResponseTypeDef,
    DeleteTaskSetRequestRequestTypeDef,
    DeleteTaskSetResponseTypeDef,
    DeploymentCircuitBreakerTypeDef,
    DeploymentConfigurationTypeDef,
    DeploymentControllerTypeDef,
    DeploymentTypeDef,
    DeregisterContainerInstanceRequestRequestTypeDef,
    DeregisterContainerInstanceResponseTypeDef,
    DeregisterTaskDefinitionRequestRequestTypeDef,
    DeregisterTaskDefinitionResponseTypeDef,
    DescribeCapacityProvidersRequestRequestTypeDef,
    DescribeCapacityProvidersResponseTypeDef,
    DescribeClustersRequestRequestTypeDef,
    DescribeClustersResponseTypeDef,
    DescribeContainerInstancesRequestRequestTypeDef,
    DescribeContainerInstancesResponseTypeDef,
    DescribeServicesRequestRequestTypeDef,
    DescribeServicesRequestServicesInactiveWaitTypeDef,
    DescribeServicesRequestServicesStableWaitTypeDef,
    DescribeServicesResponseTypeDef,
    DescribeTaskDefinitionRequestRequestTypeDef,
    DescribeTaskDefinitionResponseTypeDef,
    DescribeTaskSetsRequestRequestTypeDef,
    DescribeTaskSetsResponseTypeDef,
    DescribeTasksRequestRequestTypeDef,
    DescribeTasksRequestTasksRunningWaitTypeDef,
    DescribeTasksRequestTasksStoppedWaitTypeDef,
    DescribeTasksResponseTypeDef,
    DeviceTypeDef,
    DiscoverPollEndpointRequestRequestTypeDef,
    DiscoverPollEndpointResponseTypeDef,
    DockerVolumeConfigurationTypeDef,
    EFSAuthorizationConfigTypeDef,
    EFSVolumeConfigurationTypeDef,
    EnvironmentFileTypeDef,
    EphemeralStorageTypeDef,
    ExecuteCommandConfigurationTypeDef,
    ExecuteCommandLogConfigurationTypeDef,
    ExecuteCommandRequestRequestTypeDef,
    ExecuteCommandResponseTypeDef,
    FSxWindowsFileServerAuthorizationConfigTypeDef,
    FSxWindowsFileServerVolumeConfigurationTypeDef,
    FailureTypeDef,
    FirelensConfigurationTypeDef,
    HealthCheckTypeDef,
    HostEntryTypeDef,
    HostVolumePropertiesTypeDef,
    InferenceAcceleratorOverrideTypeDef,
    InferenceAcceleratorTypeDef,
    InstanceHealthCheckResultTypeDef,
    KernelCapabilitiesTypeDef,
    KeyValuePairTypeDef,
    LinuxParametersTypeDef,
    ListAccountSettingsRequestListAccountSettingsPaginateTypeDef,
    ListAccountSettingsRequestRequestTypeDef,
    ListAccountSettingsResponseTypeDef,
    ListAttributesRequestListAttributesPaginateTypeDef,
    ListAttributesRequestRequestTypeDef,
    ListAttributesResponseTypeDef,
    ListClustersRequestListClustersPaginateTypeDef,
    ListClustersRequestRequestTypeDef,
    ListClustersResponseTypeDef,
    ListContainerInstancesRequestListContainerInstancesPaginateTypeDef,
    ListContainerInstancesRequestRequestTypeDef,
    ListContainerInstancesResponseTypeDef,
    ListServicesRequestListServicesPaginateTypeDef,
    ListServicesRequestRequestTypeDef,
    ListServicesResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListTaskDefinitionFamiliesRequestListTaskDefinitionFamiliesPaginateTypeDef,
    ListTaskDefinitionFamiliesRequestRequestTypeDef,
    ListTaskDefinitionFamiliesResponseTypeDef,
    ListTaskDefinitionsRequestListTaskDefinitionsPaginateTypeDef,
    ListTaskDefinitionsRequestRequestTypeDef,
    ListTaskDefinitionsResponseTypeDef,
    ListTasksRequestListTasksPaginateTypeDef,
    ListTasksRequestRequestTypeDef,
    ListTasksResponseTypeDef,
    LoadBalancerTypeDef,
    LogConfigurationTypeDef,
    ManagedAgentStateChangeTypeDef,
    ManagedAgentTypeDef,
    ManagedScalingTypeDef,
    MountPointTypeDef,
    NetworkBindingTypeDef,
    NetworkConfigurationTypeDef,
    NetworkInterfaceTypeDef,
    PaginatorConfigTypeDef,
    PlacementConstraintTypeDef,
    PlacementStrategyTypeDef,
    PlatformDeviceTypeDef,
    PortMappingTypeDef,
    ProxyConfigurationTypeDef,
    PutAccountSettingDefaultRequestRequestTypeDef,
    PutAccountSettingDefaultResponseTypeDef,
    PutAccountSettingRequestRequestTypeDef,
    PutAccountSettingResponseTypeDef,
    PutAttributesRequestRequestTypeDef,
    PutAttributesResponseTypeDef,
    PutClusterCapacityProvidersRequestRequestTypeDef,
    PutClusterCapacityProvidersResponseTypeDef,
    RegisterContainerInstanceRequestRequestTypeDef,
    RegisterContainerInstanceResponseTypeDef,
    RegisterTaskDefinitionRequestRequestTypeDef,
    RegisterTaskDefinitionResponseTypeDef,
    RepositoryCredentialsTypeDef,
    ResourceRequirementTypeDef,
    ResourceTypeDef,
    ResponseMetadataTypeDef,
    RunTaskRequestRequestTypeDef,
    RunTaskResponseTypeDef,
    RuntimePlatformTypeDef,
    ScaleTypeDef,
    SecretTypeDef,
    ServiceEventTypeDef,
    ServiceRegistryTypeDef,
    ServiceTypeDef,
    SessionTypeDef,
    SettingTypeDef,
    StartTaskRequestRequestTypeDef,
    StartTaskResponseTypeDef,
    StopTaskRequestRequestTypeDef,
    StopTaskResponseTypeDef,
    SubmitAttachmentStateChangesRequestRequestTypeDef,
    SubmitAttachmentStateChangesResponseTypeDef,
    SubmitContainerStateChangeRequestRequestTypeDef,
    SubmitContainerStateChangeResponseTypeDef,
    SubmitTaskStateChangeRequestRequestTypeDef,
    SubmitTaskStateChangeResponseTypeDef,
    SystemControlTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    TaskDefinitionPlacementConstraintTypeDef,
    TaskDefinitionTypeDef,
    TaskOverrideTypeDef,
    TaskSetTypeDef,
    TaskTypeDef,
    TmpfsTypeDef,
    UlimitTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateCapacityProviderRequestRequestTypeDef,
    UpdateCapacityProviderResponseTypeDef,
    UpdateClusterRequestRequestTypeDef,
    UpdateClusterResponseTypeDef,
    UpdateClusterSettingsRequestRequestTypeDef,
    UpdateClusterSettingsResponseTypeDef,
    UpdateContainerAgentRequestRequestTypeDef,
    UpdateContainerAgentResponseTypeDef,
    UpdateContainerInstancesStateRequestRequestTypeDef,
    UpdateContainerInstancesStateResponseTypeDef,
    UpdateServicePrimaryTaskSetRequestRequestTypeDef,
    UpdateServicePrimaryTaskSetResponseTypeDef,
    UpdateServiceRequestRequestTypeDef,
    UpdateServiceResponseTypeDef,
    UpdateTaskSetRequestRequestTypeDef,
    UpdateTaskSetResponseTypeDef,
    VersionInfoTypeDef,
    VolumeFromTypeDef,
    VolumeTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> AttachmentStateChangeTypeDef:
    return {
      ...
    }
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`types-aiobotocore-ecs` version is the same as related `aiobotocore` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_ecs/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
